==> TheengsDecoder-1.5.5.tar.gz: TheengsDecoder-1.5.5/src/devices/LYWSD02_json.h <==
#include "common_props.h"

const char* _LYWSD02_json = "{\"brand\":\"Xiaomi/Mijia\",\"model\":\"e-ink Clock\",\"model_id\":\"LYWSD02\",\"tag\":\"01\",\"condition\":[\"uuid\",\"index\",0,\"fe95\",\"&\",\"servicedata\",\"index\",4,\"5b04\"],\"properties\":{\"tempc\":{\"condition\":[\"servicedata\",24,\"0410\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,4,true],\"post_proc\":[\"/\",10]},\"hum\":{\"condition\":[\"servicedata\",24,\"0610\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,4,true,false],\"post_proc\":[\"/\",10]},\"batt\":{\"condition\":[\"servicedata\",24,\"0a10\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,2,false,false]},\"mac\":{\"decoder\":[\"revmac_from_hex_data\",\"servicedata\",10]}}}";
/* R""""(
{
   "brand":"Xiaomi/Mijia",
   "model":"e-ink Clock",
   "model_id":"LYWSD02",
   "tag":"01",
   "condition":["uuid", "index", 0, "fe95", "&", "servicedata", "index", 4, "5b04"],
   "properties":{
      "tempc":{
         "condition":["servicedata", 24, "0410"],
         "decoder":["value_from_hex_data", "servicedata", 30, 4, true],
         "post_proc":["/", 10]
      },
      "hum":{
         "condition":["servicedata", 24, "0610"],
         "decoder":["value_from_hex_data", "servicedata", 30, 4, true, false],
         "post_proc":["/", 10]
      },
      "batt":{
         "condition":["servicedata", 24, "0a10"],
         "decoder":["value_from_hex_data", "servicedata", 30, 2, false, false]
      },
      "mac":{
         "decoder":["revmac_from_hex_data", "servicedata", 10]
      }
   }
})"""";*/

const char* _LYWSD02_json_props = _common_BTH_props;

==> TheengsDecoder-1.6.2.tar.gz: TheengsDecoder-1.6.2/src/devices/LYWSD02_json.h <==
#include "common_props.h"

const char* _LYWSD02_json = "{\"brand\":\"Xiaomi/Mijia\",\"model\":\"e-ink Clock\",\"model_id\":\"LYWSD02\",\"tag\":\"01\",\"condition\":[\"uuid\",\"index\",0,\"fe95\",\"&\",\"servicedata\",\"index\",4,\"5b04\"],\"properties\":{\"tempc\":{\"condition\":[\"servicedata\",24,\"0410\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,4,true],\"post_proc\":[\"/\",10]},\"hum\":{\"condition\":[\"servicedata\",24,\"0610\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,4,true,false],\"post_proc\":[\"/\",10]},\"batt\":{\"condition\":[\"servicedata\",24,\"0a10\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,2,false,false]},\"mac\":{\"decoder\":[\"revmac_from_hex_data\",\"servicedata\",10]}}}";
/* R""""(
{
   "brand":"Xiaomi/Mijia",
   "model":"e-ink Clock",
   "model_id":"LYWSD02",
   "tag":"01",
   "condition":["uuid", "index", 0, "fe95", "&", "servicedata", "index", 4, "5b04"],
   "properties":{
      "tempc":{
         "condition":["servicedata", 24, "0410"],
         "decoder":["value_from_hex_data", "servicedata", 30, 4, true],
         "post_proc":["/", 10]
      },
      "hum":{
         "condition":["servicedata", 24, "0610"],
         "decoder":["value_from_hex_data", "servicedata", 30, 4, true, false],
         "post_proc":["/", 10]
      },
      "batt":{
         "condition":["servicedata", 24, "0a10"],
         "decoder":["value_from_hex_data", "servicedata", 30, 2, false, false]
      },
      "mac":{
         "decoder":["revmac_from_hex_data", "servicedata", 10]
      }
   }
})"""";*/

const char* _LYWSD02_json_props = _common_BTHM_props;
